@@ -1,10 +1,11 @@
 """scrapli.driver.core.cisco_iosxe.async_driver"""
 from copy import deepcopy
-from typing import Any, Callable, Dict, List, Optional
+from io import BytesIO
+from typing import Any, Callable, Dict, List, Optional, Union
 
 from scrapli.driver import AsyncNetworkDriver
-from scrapli.driver.base_network_driver import PrivilegeLevel
-from scrapli.driver.core.cisco_iosxe.base_driver import PRIVS
+from scrapli.driver.core.cisco_iosxe.base_driver import FAILED_WHEN_CONTAINS, PRIVS
+from scrapli.driver.network.base_driver import PrivilegeLevel
 
 
 async def iosxe_on_open(conn: AsyncNetworkDriver) -> None:
@@ -15,10 +16,11 @@ async def iosxe_on_open(conn: AsyncNetworkDriver) -> None:
         conn: NetworkDriver object
 
     Returns:
-        N/A  # noqa: DAR202
+        None
 
     Raises:
         N/A
+
     """
     await conn.acquire_priv(desired_priv=conn.default_desired_privilege_level)
     await conn.send_command(command="terminal length 0")
@@ -33,34 +35,57 @@ async def iosxe_on_close(conn: AsyncNetworkDriver) -> None:
         conn: NetworkDriver object
 
     Returns:
-        N/A  # noqa: DAR202
+        None
 
     Raises:
         N/A
+
     """
-    # write exit directly to the transport as channel would fail to find the prompt after sending
-    # the exit command!
     await conn.acquire_priv(desired_priv=conn.default_desired_privilege_level)
-    conn.transport.write(channel_input="exit")
-    conn.transport.write(channel_input=conn.channel.comms_return_char)
+    conn.channel.write(channel_input="exit")
+    conn.channel.send_return()
 
 
 class AsyncIOSXEDriver(AsyncNetworkDriver):
     def __init__(
         self,
+        host: str,
         privilege_levels: Optional[Dict[str, PrivilegeLevel]] = None,
         default_desired_privilege_level: str = "privilege_exec",
-        auth_secondary: str = "",
+        port: Optional[int] = None,
+        auth_username: str = "",
+        auth_password: str = "",
+        auth_private_key: str = "",
+        auth_private_key_passphrase: str = "",
+        auth_strict_key: bool = True,
+        auth_bypass: bool = False,
+        timeout_socket: float = 15.0,
+        timeout_transport: float = 30.0,
+        timeout_ops: float = 30.0,
+        comms_return_char: str = "\n",
+        ssh_config_file: Union[str, bool] = False,
+        ssh_known_hosts_file: Union[str, bool] = False,
+        on_init: Optional[Callable[..., Any]] = None,
         on_open: Optional[Callable[..., Any]] = None,
         on_close: Optional[Callable[..., Any]] = None,
+        transport: str = "system",
+        transport_options: Optional[Dict[str, Any]] = None,
+        channel_log: Union[str, bool, BytesIO] = False,
+        channel_log_mode: str = "write",
+        channel_lock: bool = False,
+        logging_uid: str = "",
+        auth_secondary: str = "",
+        failed_when_contains: Optional[List[str]] = None,
         textfsm_platform: str = "cisco_iosxe",
         genie_platform: str = "iosxe",
-        failed_when_contains: Optional[List[str]] = None,
-        **kwargs: Dict[str, Any],
     ):
         """
         AsyncIOSXEDriver Object
 
+        Please see `scrapli.driver.base.base_driver.Driver` for all "base driver" arguments!
+
+        # noqa: DAR101
+
         Args:
             privilege_levels: optional user provided privilege levels, if left None will default to
                 scrapli standard privilege levels
@@ -80,13 +105,13 @@ class AsyncIOSXEDriver(AsyncNetworkDriver):
             textfsm_platform: string name of textfsm parser platform
             genie_platform: string name of cisco genie parser platform
             failed_when_contains: List of strings that indicate a command/config has failed
-            **kwargs: keyword args to pass to inherited class(es)
 
         Returns:
-            N/A  # noqa: DAR202
+            None
 
         Raises:
             N/A
+
         """
         if privilege_levels is None:
             privilege_levels = deepcopy(PRIVS)
@@ -97,21 +122,36 @@ class AsyncIOSXEDriver(AsyncNetworkDriver):
             on_close = iosxe_on_close
 
         if failed_when_contains is None:
-            failed_when_contains = [
-                "% Ambiguous command",
-                "% Incomplete command",
-                "% Invalid input detected",
-                "% Unknown command",
-            ]
+            failed_when_contains = FAILED_WHEN_CONTAINS.copy()
 
         super().__init__(
+            host=host,
+            port=port,
+            auth_username=auth_username,
+            auth_password=auth_password,
+            auth_private_key=auth_private_key,
+            auth_private_key_passphrase=auth_private_key_passphrase,
+            auth_strict_key=auth_strict_key,
+            auth_bypass=auth_bypass,
+            timeout_socket=timeout_socket,
+            timeout_transport=timeout_transport,
+            timeout_ops=timeout_ops,
+            comms_return_char=comms_return_char,
+            ssh_config_file=ssh_config_file,
+            ssh_known_hosts_file=ssh_known_hosts_file,
+            on_init=on_init,
+            on_open=on_open,
+            on_close=on_close,
+            transport=transport,
+            transport_options=transport_options,
+            channel_log=channel_log,
+            channel_log_mode=channel_log_mode,
+            channel_lock=channel_lock,
+            logging_uid=logging_uid,
             privilege_levels=privilege_levels,
             default_desired_privilege_level=default_desired_privilege_level,
             auth_secondary=auth_secondary,
             failed_when_contains=failed_when_contains,
             textfsm_platform=textfsm_platform,
             genie_platform=genie_platform,
-            on_open=on_open,
-            on_close=on_close,
-            **kwargs,
         )
